# baseapp-email-templates is now baseapp-message-templates

This package has been renamed. Use `pip install baseapp-message-templates` instead.

New package: https://pypi.org/project/baseapp-message-templates/
